@@ -50,9 +50,8 @@ Use this mode when developing and testing locally.
 
 func init() {
 
-	CreateCmd.Flags().StringSliceVarP(&(flags.CreateFlags.Input), "input", "I", nil, "inputs to the create module")
-	CreateCmd.Flags().StringSliceVarP(&(flags.CreateFlags.Generator), "generator", "G", nil, "generator tags to run, default is all")
-	CreateCmd.Flags().StringVarP(&(flags.CreateFlags.Outdir), "outdir", "O", "", "base directory to write all output to")
+	flags.SetupCreateFlags(CreateCmd.Flags(), &(flags.CreateFlags))
+
 }
 
 func CreateRun(module string, extra []string) (err error) {
@@ -67,7 +66,7 @@ var CreateCmd = &cobra.Command{
 
 	Use: "create <module path> [extra args]",
 
-	Short: "dynamic app blueprints from any git repo",
+	Short: "starter kits or blueprints from any git repo",
 
 	Long: createLong,
 
