@@ -8,14 +8,16 @@ import (
 
 	"github.com/hofstadter-io/hof/lib/mod"
 
+	"github.com/hofstadter-io/hof/cmd/hof/flags"
+
 	"github.com/hofstadter-io/hof/cmd/hof/ga"
 )
 
-var vendorLong = `make a vendored copy of dependencies`
+var vendorLong = `copy dependencies to cue.mod/pkg`
 
 func VendorRun(args []string) (err error) {
 
-	err = mod.ProcessLangs("vendor", args)
+	err = mod.Vendor(flags.RootPflags)
 	if err != nil {
 		fmt.Println(err)
 		os.Exit(1)
@@ -26,19 +28,16 @@ func VendorRun(args []string) (err error) {
 
 var VendorCmd = &cobra.Command{
 
-	Use: "vendor [langs...]",
+	Use: "vendor",
 
-	Short: "make a vendored copy of dependencies",
+	Short: "copy dependencies to cue.mod/pkg",
 
 	Long: vendorLong,
 
-	PreRun: func(cmd *cobra.Command, args []string) {
+	Run: func(cmd *cobra.Command, args []string) {
 
 		ga.SendCommandPath(cmd.CommandPath())
 
-	},
-
-	Run: func(cmd *cobra.Command, args []string) {
 		var err error
 
 		// Argument Parsing
@@ -59,7 +58,11 @@ func init() {
 
 	ohelp := VendorCmd.HelpFunc()
 	ousage := VendorCmd.UsageFunc()
+
 	help := func(cmd *cobra.Command, args []string) {
+
+		ga.SendCommandPath(cmd.CommandPath() + " help")
+
 		if extra(cmd) {
 			return
 		}
@@ -73,11 +76,9 @@ func init() {
 	}
 
 	thelp := func(cmd *cobra.Command, args []string) {
-		ga.SendCommandPath(cmd.CommandPath() + " help")
 		help(cmd, args)
 	}
 	tusage := func(cmd *cobra.Command) error {
-		ga.SendCommandPath(cmd.CommandPath() + " usage")
 		return usage(cmd)
 	}
 	VendorCmd.SetHelpFunc(thelp)
