@@ -9,17 +9,17 @@ import (
 	"github.com/hofstadter-io/hof/cmd/hof/flags"
 	"github.com/hofstadter-io/hof/cmd/hof/ga"
 
-	"github.com/hofstadter-io/hof/lib/datamodel"
+	"github.com/hofstadter-io/hof/lib/datamodel/cmd"
 )
 
-var listLong = `print available data models`
+var listLong = `print available datamodels`
 
 func ListRun(args []string) (err error) {
 
 	// you can safely comment this print out
 	// fmt.Println("not implemented")
 
-	err = datamodel.RunListFromArgs(args, flags.DatamodelPflags)
+	err = cmd.Run("list", args, flags.RootPflags, flags.DatamodelPflags)
 
 	return err
 }
@@ -32,17 +32,14 @@ var ListCmd = &cobra.Command{
 		"ls",
 	},
 
-	Short: "print available data models",
+	Short: "print available datamodels",
 
 	Long: listLong,
 
-	PreRun: func(cmd *cobra.Command, args []string) {
+	Run: func(cmd *cobra.Command, args []string) {
 
 		ga.SendCommandPath(cmd.CommandPath())
 
-	},
-
-	Run: func(cmd *cobra.Command, args []string) {
 		var err error
 
 		// Argument Parsing
@@ -63,7 +60,11 @@ func init() {
 
 	ohelp := ListCmd.HelpFunc()
 	ousage := ListCmd.UsageFunc()
+
 	help := func(cmd *cobra.Command, args []string) {
+
+		ga.SendCommandPath(cmd.CommandPath() + " help")
+
 		if extra(cmd) {
 			return
 		}
@@ -77,11 +78,9 @@ func init() {
 	}
 
 	thelp := func(cmd *cobra.Command, args []string) {
-		ga.SendCommandPath(cmd.CommandPath() + " help")
 		help(cmd, args)
 	}
 	tusage := func(cmd *cobra.Command) error {
-		ga.SendCommandPath(cmd.CommandPath() + " usage")
 		return usage(cmd)
 	}
 	ListCmd.SetHelpFunc(thelp)
