@@ -1,8 +1,12 @@
 package ga
 
 import (
+	"bytes"
+	"encoding/json"
 	"fmt"
 	"io/ioutil"
+	"net/http"
+	"net/url"
 	"os"
 	"path/filepath"
 	"strconv"
@@ -10,7 +14,6 @@ import (
 
 	"github.com/google/uuid"
 	"github.com/hofstadter-io/cinful"
-	"github.com/hofstadter-io/hof/lib/yagu"
 
 	"github.com/hofstadter-io/hof/cmd/hof/verinfo"
 )
@@ -26,8 +29,8 @@ func init() {
 	}
 	// short-circuit
 	ev := os.Getenv("HOF_TELEMETRY_DISABLED")
-	eb, _ := strconv.ParseBool(ev)
 	if ev != "" {
+		eb, _ := strconv.ParseBool(ev)
 		if eb {
 			if debug {
 				fmt.Println("telemetry disabled in env")
@@ -43,9 +46,15 @@ func init() {
 		cid = "disabled"
 		return
 	}
+
+	// workaround for running in TestScript tool
+	if strings.HasPrefix(ucd, "/no-home") {
+		ucd = strings.TrimPrefix(ucd, "/")
+	}
 	dir = filepath.Join(ucd, "hof")
 	fn = filepath.Join(dir, ".uuid")
 
+
 	// try reading
 	cid, err = readGaId()
 	if debug {
@@ -89,68 +98,6 @@ func init() {
 		fmt.Println("Error writing telemetry config, please let the devs know")
 		return
 	}
-
-	// create the ID for the first time
-	// prompting user for approval
-
-	// if not found, ask and write
-	// if ev != "" {
-	// 	if !eb {
-	// 		approve := askGaId()
-	// 	}
-	// }
-	// if !approve {
-	// 	err = writeGaId("disabled")
-	// } else {
-	// 	id, _ := uuid.NewUUID()
-	// 	cid = id.String()
-	// }
-}
-
-func SendCommandPath(cmd string) {
-	if debug {
-		fmt.Println("try sending:", cmd)
-	}
-	cs := strings.Fields(cmd)
-	c := strings.Join(cs[1:], "/")
-	l := "user"
-	if isCI {
-		l = "ci"
-	}
-
-	if debug {
-		fmt.Println("SendGaEvent:", c, l, cid)
-	}
-	if cid == "disabled" {
-		return
-	}
-
-	ua := fmt.Sprintf(
-		"%s/%s (%s %s)",
-		"hof", verinfo.Version,
-		verinfo.BuildOS, verinfo.BuildArch,
-	)
-
-	cfg := yagu.GaConfig{
-		TID: "UA-103579574-5",
-		CID: cid,
-		UA:  ua,
-		CN:  verinfo.Version,
-		CS:  verinfo.BuildOS,
-		CM:  verinfo.BuildArch,
-	}
-
-	evt := yagu.GaEvent{
-		Action:   c, // path or cmd here
-		Source:   fmt.Sprintf("%s/%s",verinfo.BuildOS, verinfo.BuildArch),
-		Category: l,
-	}
-
-	if debug {
-		fmt.Printf("sending:\n%#v\n%#v\n", cfg, evt)
-	}
-
-	yagu.SendGaEvent(cfg, evt)
 }
 
 func readGaId() (string, error) {
@@ -172,7 +119,6 @@ func readGaId() (string, error) {
 }
 
 func writeGaId(value string) error {
-
 	err := os.MkdirAll(dir, 0755)
 	if err != nil {
 		return err
@@ -186,20 +132,120 @@ func writeGaId(value string) error {
 	return nil
 }
 
-var askMsg = `We only send the command run, no args or input.
-You can disable at any time by setting
-  HOF_TELEMETRY_DISABLED=1
-
-Would you like to help by sharing very basic usage stats?`
-
-func askGaId() bool {
-	prompt := "\n(y/n) >"
-	fmt.Printf(askMsg + prompt)
-	var ans string
-	fmt.Scanln(&ans)
-	a := strings.ToLower(ans)
-	if a == "n" || a == "no" {
-		return false
+func SendCommandPath(cmd string) {
+	if cid == "disabled" {
+		return
+	}
+
+	cs := strings.Fields(cmd)
+	c := strings.Join(cs[1:], "/")
+	// cmd runner type
+	l := "user"
+	if isCI {
+		l = "ci"
+	}
+
+	vals := url.Values{}
+	vals.Add("measurement_id", "G-6CYEVMZL4R")
+
+	evt := map[string]any{
+		"name": "cmd_run",
+		"params": map[string]any{
+			"cmd": c,
+			"version": verinfo.Version,
+			"commit": verinfo.Commit,
+			"arch": verinfo.BuildArch,
+			"os": verinfo.BuildOS,
+			"runtype": l,
+			"engagement_time_msec" : 250,
+		},
+	}
+
+	//pv := map[string]any{
+	//  "name": "page_view",
+	//  "params": map[string]any{
+	//    "page_location": c,
+	//    "page_title": cmd,
+	//    "engagement_time_msec" : 250,
+	//  },
+	//}
+
+	obj := map[string]any{
+		"client_id": cid,
+		"user_id": cid,
+		"events": []map[string]any { evt },
+	}
+
+	postBody, err := json.MarshalIndent(obj, "", "  ")
+	if err != nil {
+		if debug {
+			fmt.Println("Marshal Error: ", err)
+		}
+	}
+	if debug {
+		fmt.Println("body: ", string(postBody))
+	}
+
+
+	reqBody := bytes.NewBuffer(postBody)
+
+	gaURL := "https://docs.hofstadter.io/mp/collect?"
+	//gaURL = "https://next.hofstadter.io/mp/collect?"
+	//gaURL = "https://next.hofstadter.io/debug/mp/collect?"
+	//gaURL = "http://localhost:8080/mp/collect?"
+	//gaURL = "http://localhost:8080/mp/collect?"
+	url := gaURL +	vals.Encode()
+	if debug {
+		fmt.Println(url)
+	}
+
+	resp, err := http.Post(url, "application/json", reqBody)
+
+	if resp == nil {
+		if debug {
+			fmt.Println("ga nil response")
+		}
+		return
+	}
+	if resp.Body == nil {
+		if debug {
+			fmt.Println("ga nil response body")
+		}
+		return
+	}
+
+	if debug {
+		fmt.Println(resp, err)
+	}
+
+	defer func() {
+		if resp != nil && resp.Body != nil {
+			resp.Body.Close()
+		}
+	}()
+
+	//Read the response body
+	body, err := ioutil.ReadAll(resp.Body)
+	if err != nil {
+		if debug {
+			fmt.Println("Read Error: ", resp.StatusCode, string(body), err)
+		}
+	}
+
+	if resp.StatusCode >= 500 {
+		if debug {
+			fmt.Println("Internal Error: ", resp.StatusCode, string(body), err)
+		}
+		// return body, errors.New("Internal Error: " + body)
+	}
+	if resp.StatusCode >= 400 {
+		if debug {
+			fmt.Println("Bad Request: ", resp.StatusCode, string(body))
+		}
+		// return body, errors.New("Bad Request: " + body)
+	}
+
+	if debug {
+		fmt.Println(string(body))
 	}
-	return true
 }
